@@ -1,5 +1,5 @@
 package Crypt::Passphrase;
-$Crypt::Passphrase::VERSION = '0.018';
+$Crypt::Passphrase::VERSION = '0.019';
 use strict;
 use warnings;
 
@@ -129,18 +129,17 @@ sub verify_password {
 	return 0;
 }
 
+sub recode_hash {
+	my ($self, @args) = @_;
+	return $self->{encoder}->recode_hash(@args);
+}
+
 sub curry_with_hash {
 	my ($self, $hash) = @_;
 	require Crypt::Passphrase::PassphraseHash;
 	return Crypt::Passphrase::PassphraseHash->new($self, $hash);
 }
 
-sub curry_with_password {
-	my ($self, $password) = @_;
-	my $hash = $self->hash_password($password);
-	return $self->curry_with_hash($hash);
-}
-
 1;
 
 # ABSTRACT: A module for managing passwords in a cryptographically agile manner
@@ -157,7 +156,7 @@ Crypt::Passphrase - A module for managing passwords in a cryptographically agile
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -250,6 +249,12 @@ This will check if a hash needs to be rehashed, either because it's in the wrong
 
 Calling this only ever makes sense after a password has been verified.
 
+=head2 recode_hash
+
+ $passphrase->recode_hash($hash)
+
+This recodes a hash if possible. This is mainly relevant when upgrading to a new pepper, but can also be relevant when a cipher has multiple known encodings (e.g. scrypt).
+
 =head2 curry_with_hash
 
  $passphrase->curry_with_hash($hash)
@@ -340,7 +345,7 @@ A number of integrations of Crypt::Passphrase exist:
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
