@@ -1,5 +1,5 @@
 package Crypt::Passphrase::Encoder;
-$Crypt::Passphrase::Encoder::VERSION = '0.018';
+$Crypt::Passphrase::Encoder::VERSION = '0.019';
 use strict;
 use warnings;
 
@@ -24,6 +24,11 @@ sub accepts_hash {
 	return $hash =~ $self->{accepts_hash};
 }
 
+sub recode_hash {
+	my ($self, $hash, @args) = @_;
+	return $hash;
+}
+
 1;
 
 #ABSTRACT: Base class for Crypt::Passphrase encoders
@@ -40,7 +45,7 @@ Crypt::Passphrase::Encoder - Base class for Crypt::Passphrase encoders
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 DESCRIPTION
 
@@ -48,7 +53,7 @@ This is a base class for password encoders. It is a subclass of C<Crypt::Passphr
 
 =head1 SUBCLASSING
 
-=head2 MANDATORY METHODS
+=head2 Mandatory methods
 
 It expects the subclass to implement the following four methods:
 
@@ -76,7 +81,13 @@ This method will return true if the password hash needs a rehash. This may eithe
 
 This method returns the types of crypt entries this validator supports. This is used to implement C<accepts_hash>.
 
-=head2 PROVIDED METHODS
+=head3 Optional methods
+
+=head3 recode_hash
+
+ $encoder->recode_hash($hash)
+
+=head2 Provided methods
 
 It provides the following methods to aid in implementing encoders:
 
@@ -94,7 +105,7 @@ This compares two strings in a way that resists timing attacks.
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
