@@ -1,5 +1,5 @@
 package Crypt::Passphrase::Pepper::Base;
-$Crypt::Passphrase::Pepper::Base::VERSION = '0.018';
+$Crypt::Passphrase::Pepper::Base::VERSION = '0.019';
 use strict;
 use warnings;
 
@@ -14,6 +14,7 @@ sub new {
 
 	croak('No peppers given') if not defined $args{active};
 	croak("Invalid pepper name '$args{active}'") if $args{active} =~ /\W/;
+	croak('No hashing algorithm given') if not defined $args{algorithm};
 
 	my $self = bless {
 		%args,
@@ -27,8 +28,6 @@ sub _to_inner {
 	my $hash = shift;
 	if ($hash =~ s/ (?<= \A \$) ([\w-]+?)-pepper-([\w-]+) \$ v=1 , id=([^\$,]+) /$1/x) {
 		return ($hash, $2, $3);
-	} elsif ($hash =~ s/ (?<= \A \$) peppered-(\w+) \$ v=1 , alg=([^\$,]+) , id=([^\$,]+) /$1/x) {
-		return ($hash, $2, $3);
 	} else {
 		return;
 	}
@@ -93,7 +92,7 @@ Crypt::Passphrase::Pepper::Base - A base class for pre-hashing pepper implementa
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 DESCRIPTION
 
@@ -115,7 +114,7 @@ The identifier of the active pepper.
 
 =head3 algorithm
 
-The hash that is used for password creation, it must be one from the C<supported_hashes> list
+The hash that is used for password creation.
 
 =head2 Mandatory methods
 
@@ -127,9 +126,13 @@ It expects the subclass to implement the following method:
 
 This should prehash the C<$password> with C<$algorithm> and the pepper named by C<$id>.
 
+=head3 supported_hashes
+
+This should return a list of hashes that are supported.
+
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
