@@ -1,5 +1,5 @@
 package Crypt::Passphrase::SHA1::Base64;
-$Crypt::Passphrase::SHA1::Base64::VERSION = '0.018';
+$Crypt::Passphrase::SHA1::Base64::VERSION = '0.019';
 use strict;
 use warnings;
 
@@ -40,7 +40,7 @@ Crypt::Passphrase::SHA1::Base64 - Validate against base64ed SHA1 hashes with Cry
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,7 @@ This has no configuration and will try to match any value that looks like 20 byt
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
